import EventEmitter from "eventemitter3";
import { RtpCapabilities, RtpEncodingParameters } from '../RtpParameters';
export declare type HandlerFactory = () => HandlerInterface;
export declare type HandlerRunOptions = {
    direction: 'send' | 'recv';
    iceServers?: RTCIceServer[];
    iceTransportPolicy?: RTCIceTransportPolicy;
};
export declare type HandlerSetLocalOfferSdpOptions = {
    mediastream?: MediaStream;
    encodings?: RtpEncodingParameters[];
};
export declare type HandlerSetLocalOfferSdpResult = {
    localOfferSdp: string;
};
export declare type HandlerSetRemoteAnswerSdpOptions = {
    remoteAnswerSdp: string;
    candidateArray: RTCIceCandidateInit[];
};
export declare abstract class HandlerInterface extends EventEmitter {
    constructor();
    abstract get name(): string;
    abstract close(): void;
    abstract getNativeRtpCapabilities(): Promise<RtpCapabilities>;
    abstract run(options: HandlerRunOptions): void;
    abstract setLocalOfferSdp(options?: HandlerSetLocalOfferSdpOptions): Promise<void>;
    abstract replaceTrack(track: MediaStreamTrack): Promise<void>;
    abstract setRemoteAnswerSdp(options: HandlerSetRemoteAnswerSdpOptions): Promise<void>;
    abstract stopTransceiver(): void;
    abstract setBitrateValue(bitRate: number): void;
    abstract transportStats(): void;
}
